==> scala-relay-compiler-0.4.0.tgz: package/example/out/DictionaryQuery.scala <==
/**
 * scala 
 * @relayHash 497b1114cb84b59d1d2959795a2d05eb
 * Generated, DON'T MANUALLY EDIT.
 */
package relay.generated;
/*::
import type {ConcreteBatch} from 'relay-runtime';

objName:      batch
docType:      ConcreteBatch
concreteText: {
  "fragment": {
    "argumentDefinitions": [],
    "kind": "Fragment",
    "metadata": null,
    "name": "DictionaryQuery",
    "selections": [
      {
        "kind": "LinkedField",
        "alias": null,
        "args": null,
        "concreteType": "Word",
        "name": "dictionary",
        "plural": true,
        "selections": [
          {
            "kind": "FragmentSpread",
            "name": "DictionaryComponent_word",
            "args": null
          }
        ],
        "storageKey": null
      }
    ],
    "type": "Root"
  },
  "id": null,
  "kind": "Batch",
  "metadata": {},
  "name": "DictionaryQuery",
  "query": {
    "argumentDefinitions": [],
    "kind": "Root",
    "name": "DictionaryQuery",
    "operation": "query",
    "selections": [
      {
        "kind": "LinkedField",
        "alias": null,
        "args": null,
        "concreteType": "Word",
        "name": "dictionary",
        "plural": true,
        "selections": [
          {
            "kind": "InlineFragment",
            "type": "Word",
            "selections": [
              {
                "kind": "ScalarField",
                "alias": null,
                "args": null,
                "name": "id",
                "storageKey": null
              },
              {
                "kind": "LinkedField",
                "alias": null,
                "args": null,
                "concreteType": "WordDefinition",
                "name": "definition",
                "plural": false,
                "selections": [
                  {
                    "kind": "ScalarField",
                    "alias": null,
                    "args": null,
                    "name": "text",
                    "storageKey": null
                  },
                  {
                    "kind": "ScalarField",
                    "alias": null,
                    "args": null,
                    "name": "image",
                    "storageKey": null
                  },
                  {
                    "kind": "ScalarField",
                    "alias": null,
                    "args": null,
                    "name": "id",
                    "storageKey": null
                  }
                ],
                "storageKey": null
              }
            ]
          }
        ],
        "storageKey": null
      }
    ]
  },
  "text": "query DictionaryQuery {\n  dictionary {\n    ...DictionaryComponent_word\n  }\n}\n\nfragment DictionaryComponent_word on Word {\n  id\n  definition {\n    ...DictionaryComponent_definition\n    text\n    id\n  }\n}\n\nfragment DictionaryComponent_definition on WordDefinition {\n  text\n  image\n}\n"
};
*/

import _root_.scala.scalajs.js

trait DictionaryQuery extends js.Object {
  /** Combined the fields on a spread: DictionaryComponent_word */ 
   val dictionary : DictionaryComponent_word
}


/*
query DictionaryQuery {
  dictionary {
    ...DictionaryComponent_word
  }
}

fragment DictionaryComponent_word on Word {
  id
  definition {
    ...DictionaryComponent_definition
    text
    id
  }
}

fragment DictionaryComponent_definition on WordDefinition {
  text
  image
}
*/

object DictionaryQuery  {

  

  val ast: _root_.scala.scalajs.js.Any = _root_.scala.scalajs.js.eval("""{
  "fragment": {
    "argumentDefinitions": [],
    "kind": "Fragment",
    "metadata": null,
    "name": "DictionaryQuery",
    "selections": [
      {
        "kind": "LinkedField",
        "alias": null,
        "args": null,
        "concreteType": "Word",
        "name": "dictionary",
        "plural": true,
        "selections": [
          {
            "kind": "FragmentSpread",
            "name": "DictionaryComponent_word",
            "args": null
          }
        ],
        "storageKey": null
      }
    ],
    "type": "Root"
  },
  "id": null,
  "kind": "Batch",
  "metadata": {},
  "name": "DictionaryQuery",
  "query": {
    "argumentDefinitions": [],
    "kind": "Root",
    "name": "DictionaryQuery",
    "operation": "query",
    "selections": [
      {
        "kind": "LinkedField",
        "alias": null,
        "args": null,
        "concreteType": "Word",
        "name": "dictionary",
        "plural": true,
        "selections": [
          {
            "kind": "InlineFragment",
            "type": "Word",
            "selections": [
              {
                "kind": "ScalarField",
                "alias": null,
                "args": null,
                "name": "id",
                "storageKey": null
              },
              {
                "kind": "LinkedField",
                "alias": null,
                "args": null,
                "concreteType": "WordDefinition",
                "name": "definition",
                "plural": false,
                "selections": [
                  {
                    "kind": "ScalarField",
                    "alias": null,
                    "args": null,
                    "name": "text",
                    "storageKey": null
                  },
                  {
                    "kind": "ScalarField",
                    "alias": null,
                    "args": null,
                    "name": "image",
                    "storageKey": null
                  },
                  {
                    "kind": "ScalarField",
                    "alias": null,
                    "args": null,
                    "name": "id",
                    "storageKey": null
                  }
                ],
                "storageKey": null
              }
            ]
          }
        ],
        "storageKey": null
      }
    ]
  },
  "text": "query DictionaryQuery {\n  dictionary {\n    ...DictionaryComponent_word\n  }\n}\n\nfragment DictionaryComponent_word on Word {\n  id\n  definition {\n    ...DictionaryComponent_definition\n    text\n    id\n  }\n}\n\nfragment DictionaryComponent_definition on WordDefinition {\n  text\n  image\n}\n"
}""")
  val query: String = """"""
}

==> scala-relay-compiler-0.5.0.tgz: package/example/out/DictionaryQuery.scala <==
/**
 * scala 
 * @relayHash 497b1114cb84b59d1d2959795a2d05eb
 * Generated, DON'T MANUALLY EDIT.
 */
package relay.generated
/*

objName:      batch
docType:      ConcreteBatch
*/

import _root_.scala.scalajs.js

trait DictionaryQuery extends js.Object {
  /** Combined the fields on a spread: DictionaryComponent_word */ 
   val dictionary : DictionaryComponent_word
}


/*
query DictionaryQuery {
  dictionary {
    ...DictionaryComponent_word
  }
}

fragment DictionaryComponent_word on Word {
  id
  definition {
    ...DictionaryComponent_definition
    text
    id
  }
}

fragment DictionaryComponent_definition on WordDefinition {
  text
  image
}
*/

object DictionaryQuery extends _root_.relay.graphql.GenericGraphQLTaggedNode {

  

  val query: _root_.relay.graphql.ConcreteBatch = _root_.scala.scalajs.js.JSON.parse("""{
  "fragment": {
    "argumentDefinitions": [],
    "kind": "Fragment",
    "metadata": null,
    "name": "DictionaryQuery",
    "selections": [
      {
        "kind": "LinkedField",
        "alias": null,
        "args": null,
        "concreteType": "Word",
        "name": "dictionary",
        "plural": true,
        "selections": [
          {
            "kind": "FragmentSpread",
            "name": "DictionaryComponent_word",
            "args": null
          }
        ],
        "storageKey": null
      }
    ],
    "type": "Root"
  },
  "id": null,
  "kind": "Batch",
  "metadata": {},
  "name": "DictionaryQuery",
  "query": {
    "argumentDefinitions": [],
    "kind": "Root",
    "name": "DictionaryQuery",
    "operation": "query",
    "selections": [
      {
        "kind": "LinkedField",
        "alias": null,
        "args": null,
        "concreteType": "Word",
        "name": "dictionary",
        "plural": true,
        "selections": [
          {
            "kind": "InlineFragment",
            "type": "Word",
            "selections": [
              {
                "kind": "ScalarField",
                "alias": null,
                "args": null,
                "name": "id",
                "storageKey": null
              },
              {
                "kind": "LinkedField",
                "alias": null,
                "args": null,
                "concreteType": "WordDefinition",
                "name": "definition",
                "plural": false,
                "selections": [
                  {
                    "kind": "ScalarField",
                    "alias": null,
                    "args": null,
                    "name": "text",
                    "storageKey": null
                  },
                  {
                    "kind": "ScalarField",
                    "alias": null,
                    "args": null,
                    "name": "image",
                    "storageKey": null
                  },
                  {
                    "kind": "ScalarField",
                    "alias": null,
                    "args": null,
                    "name": "id",
                    "storageKey": null
                  }
                ],
                "storageKey": null
              }
            ]
          }
        ],
        "storageKey": null
      }
    ]
  },
  "text": "query DictionaryQuery {\n  dictionary {\n    ...DictionaryComponent_word\n  }\n}\n\nfragment DictionaryComponent_word on Word {\n  id\n  definition {\n    ...DictionaryComponent_definition\n    text\n    id\n  }\n}\n\nfragment DictionaryComponent_definition on WordDefinition {\n  text\n  image\n}\n"
}""").asInstanceOf[_root_.relay.graphql.ConcreteBatch]
  val devText: String = """"""
}
